#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'extracter/constants/constants.rb'
# =========================================================================== #
module Extracter

  # ========================================================================= #
  # === N
  # ========================================================================= #
  N = "\n"

  # ========================================================================= #
  # === Extracter::ARRAY_REGISTERED_ARCHIVES
  #
  # Archives that can be extracted, have to be registered in this Array.
  #
  # This Array has to be sorted alphabetically.
  #
  # The libreoffice format .odt is just like .zip.
  # ========================================================================= #
  ARRAY_REGISTERED_ARCHIVES = %w(
    7z
    apk
    apkg
    bin
    bz2
    deb
    gem
    gz
    img
    iso
    jar
    lz
    lzma
    odt
    mp4
    pdf
    rar
    rpm
    squashfs
    sxz
    tar
    taz
    tbz
    tgz
    txz
    xpi
    xz
    zip
    Z
    zst
  )

  # ========================================================================= #
  # === TEMP_DIR
  #
  # Set the temp dir here.
  # ========================================================================= #
  if ENV['MY_TEMP']
    TEMP_DIR = "#{ENV['MY_TEMP']}/"
  else
    # ======================================================================= #
    # If this environment variable is unavailable then use a conservative
    # default value.
    # ======================================================================= #
    TEMP_DIR = '/tmp/'
  end

  # ========================================================================= #
  # === UNPACK_COMMAND_TO_USE_ON_WINDOWS
  #
  # The full commandline when on windows will look like this:
  #
  #   7z x -so C:\home\x\src\htop\htop-3.0.5.tar.xz | 7z x -si -ttar
  #
  # This was used in the RBT project, in the past, e. g. via code
  # such as:
  #
  #   cmd = '7z x "'.dup
  #   cmd << i
  #   cmd << '" -so | 7z x -aoa -si -ttar -o"'+program_name_and_program_version?.to_s+'"'
  #        
  # ========================================================================= #
  UNPACK_COMMAND_TO_USE_ON_WINDOWS = '7z x -so '

  # ========================================================================= #
  # === SECOND_UNPACK_COMMAND_TO_USE_ON_WINDOWS
  # ========================================================================= #
  SECOND_UNPACK_COMMAND_TO_USE_ON_WINDOWS = '7z x -si -ttar'

  # ========================================================================= #
  # === COMMAND_TO_EXTRACT_TGZ_FILES
  #
  # This is specifically for .tgz files.
  # ========================================================================= #
  COMMAND_TO_EXTRACT_TGZ_FILES = 'tar zxvf'

  # ========================================================================= #
  # === COMMAND_TO_EXTRACT_LZ_FILES
  # ========================================================================= #
  COMMAND_TO_EXTRACT_LZ_FILES = 'tar --lzip -xvf'

  # ========================================================================= #
  # === COMMAND_TO_EXTRACT_TAR_XZ_FILES
  # ========================================================================= #
  COMMAND_TO_EXTRACT_TAR_XZ_FILES = 'tar -xvf'

  # ========================================================================= #
  # === COMMAND_TO_EXTRACT_LZMA_FILES
  # ========================================================================= #
  COMMAND_TO_EXTRACT_LZMA_FILES = 'unlzma'

  # ========================================================================= #
  # === COMMAND_TO_EXTRACT_DEB_FILES
  # ========================================================================= #
  COMMAND_TO_EXTRACT_DEB_FILES = 'ar -x'

  # ========================================================================= #
  # === COMMAND_TO_EXTRACT_ZST_ARCHIVES
  # ========================================================================= #
  COMMAND_TO_EXTRACT_ZST_ARCHIVES = 'tar -I zstd -xvf'

  # ========================================================================= #
  # === COMMAND_TO_EXTRACT_TAR_FILES
  # ========================================================================= #
  COMMAND_TO_EXTRACT_TAR_FILES = 'tar -xvf'

  # ========================================================================= #
  # === GEM_UNPACK_COMMAND
  #
  # The command to use to unpack ruby .gems.
  #
  # We can pass the ---target=DIR syntax to extract to a specific location.
  # ========================================================================= #
  GEM_UNPACK_COMMAND = 'gem unpack'

  # ========================================================================= #
  # === COMMAND_TO_EXTRACT_BSDTAR_ARCHIVES
  #
  # This command is to specifically extract rpm-archives.
  # ========================================================================= #
  COMMAND_TO_EXTRACT_BSDTAR_ARCHIVES = 'bsdtar xfv'

  # ========================================================================= #
  # === COMMAND_TO_EXTRACT_TAR_BZ2_FILES
  # ========================================================================= #
  COMMAND_TO_EXTRACT_TAR_BZ2_FILES = 'tar -xjvf'

  # ========================================================================= #
  # === COMMAND_TO_EXTRACT_JAR_ARCHIVES
  # ========================================================================= #
  COMMAND_TO_EXTRACT_JAR_ARCHIVES = 'jar xvf'

end
