#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'extracter/toplevel_methods/is_this_a_valid_archive.rb'
# Extracter.is_this_a_valid_archive?
# =========================================================================== #
module Extracter

  require 'extracter/constants/constants.rb'

  # ========================================================================= #
  # === Extracter.return_pwd
  # ========================================================================= #
  def self.return_pwd
    "#{Dir.pwd}/".squeeze('/')
  end

  # ========================================================================= #
  # === Extracter.are_we_on_windows?
  #
  # This method can be used to determine whether we are on windows (as
  # our primary platform) or whether we are not.
  # ========================================================================= #
  def self.are_we_on_windows?
    RUBY_PLATFORM.include?('win') or
    RUBY_PLATFORM.include?('mingw')
  end

  # ========================================================================= #
  # === Extracter.are_we_on_windows?
  # ========================================================================= #
  def self.this_on_windows(i)
    _ = UNPACK_COMMAND_TO_USE_ON_WINDOWS+' '+
        File.absolute_path(i)+
        ' | '+
        SECOND_UNPACK_COMMAND_TO_USE_ON_WINDOWS
    esystem _
  end

  # ========================================================================= #
  # === Extracter.esystem
  # ========================================================================= #
  def self.esystem(i)
    puts i
    system(i)
  end

  # ========================================================================= #
  # === Extracter.remove_archive_type
  #
  # This method will remove suffix-types from a given input String.
  # ========================================================================= #
  def self.remove_archive_type(i)
    return i.delete_suffix('.xz').
             delete_suffix('.tgz').
             delete_suffix('.bz2').
             delete_suffix('.gz').
             delete_suffix('.tar').
             delete_suffix('.zip').
             delete_suffix('.gem')
  end; self.instance_eval { alias remove_file_suffix remove_archive_type } # === Extracter.remove_file_suffix

  # ========================================================================= #
  # === Extracter.is_this_a_valid_archive?
  #
  # Query whether the input given to this method is a valid archive.
  #
  # This allows us to determine whether the Extracter project can
  # deal with the given archive at hand or whether it can not.
  #
  # The registered formats are stored in the constant
  # ARRAY_REGISTERED_ARCHIVES.
  # ========================================================================= #
  def self.is_this_a_valid_archive?(
      i, # The given input, such as "foobar.zip".
      array_registered_archives = ARRAY_REGISTERED_ARCHIVES
    )
    if i.is_a? Array
      i = i.first
    end
    return_value = false
    array_registered_archives.each {|entry|
      return_value = true if i =~ /#{entry}$/i
    }
    return return_value
  end; self.instance_eval { alias is_archive?              is_this_a_valid_archive? } # === Extracter.is_archive?
       self.instance_eval { alias is_this_a_valid_archive? is_this_a_valid_archive? } # === Extracter.is_this_a_valid_archive?

end; Extract = Extracter # And keep a pseudo-alias here.

if __FILE__ == $PROGRAM_NAME
  alias e puts
  e
  e 'Are we on windows? '+Extracter.are_we_on_windows?.to_s
  e
  pp Extracter.is_this_a_valid_archive?(ARGV)
  e
end
